You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by ms...@apache.org on 2022/08/22 14:13:20 UTC

[openoffice] branch AOO42X updated: Rename PaintBorderAndShadow -> PaintPageBorder

This is an automated email from the ASF dual-hosted git repository.

mseidel pushed a commit to branch AOO42X
in repository https://gitbox.apache.org/repos/asf/openoffice.git


The following commit(s) were added to refs/heads/AOO42X by this push:
     new a4b2faf08a Rename PaintBorderAndShadow -> PaintPageBorder
a4b2faf08a is described below

commit a4b2faf08ac74a2260fb30eddac41c8849335106
Author: mseidel <ms...@apache.org>
AuthorDate: Mon Aug 22 16:12:05 2022 +0200

    Rename PaintBorderAndShadow -> PaintPageBorder
    
    (cherry picked from commit 349543177130a4ef2aa2828e9e63c9dfa2ad2986)
---
 main/sw/source/core/inc/pagefrm.hxx            |  6 +++---
 main/sw/source/core/layout/paintfrm.cxx        | 12 ++++++------
 main/sw/source/core/view/pagepreviewlayout.cxx |  6 +++---
 3 files changed, 12 insertions(+), 12 deletions(-)

diff --git a/main/sw/source/core/inc/pagefrm.hxx b/main/sw/source/core/inc/pagefrm.hxx
index 255f8731d2..335a083e92 100644
--- a/main/sw/source/core/inc/pagefrm.hxx
+++ b/main/sw/source/core/inc/pagefrm.hxx
@@ -354,9 +354,9 @@ public:
         input parameter - instance of the view shell, on which the output
         has to be generated.
     */
-    static void PaintBorderAndShadow( const SwRect& _rPageRect,
-                                      ViewShell*    _pViewShell,
-                                      bool bRightSidebar );
+    static void PaintPageBorder( const SwRect& _rPageRect,
+                                 ViewShell*    _pViewShell,
+                                 bool bRightSidebar );
 
     /** get bound rectangle of border and shadow for repaints
 
diff --git a/main/sw/source/core/layout/paintfrm.cxx b/main/sw/source/core/layout/paintfrm.cxx
index b73c24cdfb..4522f2a7a8 100644
--- a/main/sw/source/core/layout/paintfrm.cxx
+++ b/main/sw/source/core/layout/paintfrm.cxx
@@ -3053,11 +3053,11 @@ SwRootFrm::Paint(SwRect const& rRect, SwPrintData const*const pPrintData) const
 
                 pPage->Paint( aPaintRect );
 
-                // no paint of page border and shadow, if writer is in place mode.
+                // no paint of page border if writer is in place mode.
                 if( pSh->GetWin() && pSh->GetDoc()->GetDocShell() &&
                     !pSh->GetDoc()->GetDocShell()->IsInPlaceActive() )
                 {
-                    SwPageFrm::PaintBorderAndShadow( pPage->Frm(), pSh, bRightSidebar );
+                    SwPageFrm::PaintPageBorder( pPage->Frm(), pSh, bRightSidebar );
                     SwPageFrm::PaintNotesSidebar( pPage->Frm(), pSh, pPage->GetPhyPageNum(), bRightSidebar);
                 }
 
@@ -3151,7 +3151,7 @@ SwRootFrm::Paint(SwRect const& rRect, SwPrintData const*const pPrintData) const
                 pSh->GetOut()->SetFont( aOldFont );
                 // paint border for empty page (shadow removed now)
                 // OD 19.02.2003 #107369# - use new method to paint page border
-                SwPageFrm::PaintBorderAndShadow( aEmptyPageRect, pSh, bRightSidebar );
+                SwPageFrm::PaintPageBorder( aEmptyPageRect, pSh, bRightSidebar );
                 SwPageFrm::PaintNotesSidebar( aEmptyPageRect, pSh, pPage->GetPhyPageNum(), bRightSidebar);
 
                 {
@@ -5523,9 +5523,9 @@ const sal_Int8 SwPageFrm::mnBorderPxWidth = 1;
 
     @author OD
 */
-/*static*/ void SwPageFrm::PaintBorderAndShadow( const SwRect& _rPageRect,
-                                                 ViewShell*    _pViewShell,
-                                                 bool bRightSidebar )
+/*static*/ void SwPageFrm::PaintPageBorder( const SwRect& _rPageRect,
+                                            ViewShell*    _pViewShell,
+                                            bool bRightSidebar )
 {
     // --> FME 2004-06-24 #i16816# tagged pdf support
     SwTaggedPDFHelper aTaggedPDFHelper( 0, 0, 0, *_pViewShell->GetOut() );
diff --git a/main/sw/source/core/view/pagepreviewlayout.cxx b/main/sw/source/core/view/pagepreviewlayout.cxx
index 1302128695..74a90b11c4 100644
--- a/main/sw/source/core/view/pagepreviewlayout.cxx
+++ b/main/sw/source/core/view/pagepreviewlayout.cxx
@@ -1149,7 +1149,7 @@ bool SwPagePreviewLayout::Paint( const Rectangle _aOutRect ) const
                 pOutputDev->SetFont( aOldFont );
                 // paint border for empty page (shadow removed now)
                 // OD 19.02.2003 #107369# - use new method to paint page border
-                SwPageFrm::PaintBorderAndShadow( aPageRect, &mrParentViewShell, true );
+                SwPageFrm::PaintPageBorder( aPageRect, &mrParentViewShell, true );
             }
             else
             {
@@ -1164,7 +1164,7 @@ bool SwPagePreviewLayout::Paint( const Rectangle _aOutRect ) const
                     SwPageFrm::GetBorderAndShadowBoundRect( SwRect( aPageRect ), &mrParentViewShell, aPageBorderRect, true );
                     const Region aDLRegion(aPageBorderRect.SVRect());
                     mrParentViewShell.DLPrePaint2(aDLRegion);
-                    SwPageFrm::PaintBorderAndShadow( aPageRect, &mrParentViewShell, true );
+                    SwPageFrm::PaintPageBorder( aPageRect, &mrParentViewShell, true );
                     mrParentViewShell.DLPostPaint2(true);
                 }
                 // <--
@@ -1289,7 +1289,7 @@ void SwPagePreviewLayout::_PaintSelectMarkAtPage(
     SwRect aPageRect( _aSelectedPrevwPage->aLogicPos,
                          _aSelectedPrevwPage->aPageSize );
     // OD 19.02.2003 #107369# - use aligned page rectangle, as it is used for
     // page border paint - see <SwPageFrm::PaintBorderAndShadow(..)>
     ::SwAlignRect( aPageRect, &mrParentViewShell);
     Rectangle aPxPageRect = pOutputDev->LogicToPixel( aPageRect.SVRect() );
@@ -1289,7 +1289,7 @@ void SwPagePreviewLayout::_PaintSelectMarkAtPage(
                          _aSelectedPrevwPage->aPageSize );
     // OD 19.02.2003 #107369# - use aligned page rectangle, as it is used for
-    // page border paint - see <SwPageFrm::PaintBorderAndShadow(..)>
+    // page border paint - see <SwPageFrm::PaintPageBorder(..)>
     ::SwAlignRect( aPageRect, &mrParentViewShell);
     Rectangle aPxPageRect = pOutputDev->LogicToPixel( aPageRect.SVRect() );